pub struct CompileCommand {
pub directory: String,
pub command: String,
pub file: String,
}Fields
directory: StringThe working directory of the compilation. All paths specified in the command or file fields must be either absolute or relative to this directory.
command: StringThe compile command as a single shell-escaped string. Arguments may be shell quoted and escaped following platform conventions, with “ and \ being the only special characters. Shell expansion is not supported.
file: StringThe main translation unit source processed by this compilation step. This is used by tools as the key into the compilation database. There can be multiple command objects for the same file, for example if the same source file is compiled with different configurations.